pub struct ProtocolHandlerUpdateRegistration {
pub scheme: String,
pub url: ServoUrl,
pub register_or_unregister: RegisterOrUnregister,
}Expand description
A request from Servo to embedder to register or unregister a custom protocol handler for a scheme, typically triggered by web content. See https://html.spec.whatwg.org/multipage/#custom-handlers
Fields
scheme: StringThe scheme for the protocol handler.
url: ServoUrlThe URL to navigate to when handling requests for scheme.
register_or_unregister: RegisterOrUnregisterWhether this update is to register or unregister the protocol handler.